==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/PaneHeaderConnectionEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { PaneHeaderElement } from "./PaneHeaderElement";
/**
 * @hidden
 */
var PaneHeaderConnectionEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PaneHeaderConnectionEventArgsDetail, _super);
    function PaneHeaderConnectionEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.n = this.e;
        },
        enumerable: false,
        configurable: true
    });
    PaneHeaderConnectionEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.d.l("pane", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("pane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.d.l("element", function (a) { return new PaneHeaderElement(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("element", value_);
        },
        enumerable: false,
        configurable: true
    });
    PaneHeaderConnectionEventArgsDetail.$t = markType(PaneHeaderConnectionEventArgsDetail, 'PaneHeaderConnectionEventArgsDetail');
    return PaneHeaderConnectionEventArgsDetail;
}(Base));
export { PaneHeaderConnectionEventArgsDetail };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/PaneHeaderConnectionEventArgsDetail.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { ContentPane } from "./ContentPane";
import { PaneHeaderElement } from "./PaneHeaderElement";
/**
 * @hidden
 */
var PaneHeaderConnectionEventArgsDetail = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PaneHeaderConnectionEventArgsDetail, _super);
    function PaneHeaderConnectionEventArgsDetail() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.e = null;
        return _this;
    }
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "nativeElement", {
        get: function () {
            return this.e;
        },
        set: function (a) {
            this.e = a;
            this.c.o = this.e;
        },
        enumerable: false,
        configurable: true
    });
    PaneHeaderConnectionEventArgsDetail.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("pane", function (a) { return new ContentPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("pane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PaneHeaderConnectionEventArgsDetail.prototype, "b", {
        get: function () {
            var ret_ = this.d.m("element", function (a) { return new PaneHeaderElement(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("element", value_);
        },
        enumerable: false,
        configurable: true
    });
    PaneHeaderConnectionEventArgsDetail.$t = markType(PaneHeaderConnectionEventArgsDetail, 'PaneHeaderConnectionEventArgsDetail');
    return PaneHeaderConnectionEventArgsDetail;
}(Base));
export { PaneHeaderConnectionEventArgsDetail };
